@@ -22,6 +22,7 @@ import rdflib
 from django.utils.translation import ugettext as _
 
 from wirecloud.commons.utils.template.base import is_valid_name, is_valid_vendor, is_valid_version, TemplateParseException
+from wirecloud.commons.utils.http import parse_mime_type
 
 # Namespaces used by rdflib
 WIRE = rdflib.Namespace("http://wirecloud.conwet.fi.upm.es/ns/widget#")
@@ -65,7 +66,6 @@ class RDFTemplateParser(object):
         self._info = {}
         self._translation_indexes = {}
         self._translations = {}
-        self._url_fields = []
 
         # check if is a mashup, a widget or an operator
         for type_ in self._graph.subjects(RDF['type'], WIRE['Widget']):
@@ -88,34 +88,41 @@ class RDFTemplateParser(object):
 
     def _get_translation_field(self, namespace, element, subject, translation_name, required=True, **kwargs):
 
-        element_num = 0
-        translations = {}
+        translated = False
+        base_value = None
 
         for field_element in self._graph.objects(subject, namespace[element]):
-            element_num = element_num + 1
             if field_element.language:
-                translations[unicode(field_element.language)] = unicode(field_element)
-                #This field is necesary in order to prevent a problem in case only existed 1 field but it had a language tag
-                translations['no_translation'] = unicode(field_element)
+                translated = True
+
+                if field_element.language not in self._translations:
+                    self._translations[unicode(field_element.language)] = {}
+
+                self._translations[unicode(field_element.language)][translation_name] = unicode(field_element)
             else:
-                translations['no_translation'] = unicode(field_element)
+                base_value = unicode(field_element)
 
-        if element_num == 1:
-            return translations['no_translation']
+        if base_value is not None and translated is True:
+            if 'en' not in self._translations:
+                self._translations['en'] = {}
 
-        elif element_num > 1:
+            self._translations['en'][translation_name] = base_value
+
+        if translated is True:
             self._add_translation_index(translation_name, **kwargs)
-            for k, v in translations.iteritems():
-                if k not in self._translations:
-                    self._translations[k] = {}
-                self._translations[k][translation_name] = v
             return '__MSG_' + translation_name + '__'
 
-        elif element_num == 0 and required:
+        elif base_value is None and required:
+
             msg = _('missing required field: %(field)s')
             raise TemplateParseException(msg % {'field': element})
 
+        elif base_value is not None:
+
+            return base_value
+
         else:
+
             return ''
 
     def _get_field(self, namespace, element, subject, required=True, id_=False, default=''):
@@ -136,11 +143,6 @@ class RDFTemplateParser(object):
                 result = default
         return result
 
-    def _get_url_field(self, field, *args, **kwargs):
-
-        self._url_fields.append(field)
-        return self._get_field(*args, **kwargs)
-
     def _parse_extra_info(self):
 
         if self._info['type'] == 'widget' or self._info['type'] == 'operator':
@@ -182,7 +184,8 @@ class RDFTemplateParser(object):
         author = self._get_field(DCTERMS, 'creator', self._rootURI, id_=True)
         self._info['author'] = self._get_field(FOAF, 'name', author)
 
-        self._info['image_uri'] = self._get_url_field('image_uri', WIRE, 'hasImageUri', self._rootURI)
+        self._info['image_uri'] = self._get_field(WIRE, 'hasImageUri', self._rootURI)
+        self._info['iphone_image_uri'] = self._get_field(WIRE, 'hasiPhoneImageUri', self._rootURI, required=False)
 
         self._info['doc_uri'] = self._get_field(FOAF, 'page', self._rootURI, required=False)
 
@@ -221,22 +224,28 @@ class RDFTemplateParser(object):
 
         wiring_element = self._get_field(wiring_type, wiring_property, self._rootURI, id_=True, required=False)
 
-        for input_endpoint in self._graph.objects(wiring_element, WIRE['hasInputEndpoint']):
+        sorted_inputs = sorted(self._graph.objects(wiring_element, WIRE['hasInputEndpoint']), key=lambda source: possible_int(self._get_field(WIRE, 'index', source, required=False)))
+
+        for input_endpoint in sorted_inputs:
+            var_name = self._get_field(DCTERMS, 'title', input_endpoint, required=True)
             self._info['wiring']['inputs'].append({
-                'name': self._get_field(DCTERMS, 'title', input_endpoint, required=False),
+                'name': var_name,
                 'type': self._get_field(WIRE, 'type', input_endpoint, required=False),
-                'label': self._get_translation_field(RDFS, 'label', input_endpoint, 'inputLabel', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', input_endpoint, required=False)),
-                'description': self._get_translation_field(DCTERMS, 'description', input_endpoint, 'inputDescription', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', input_endpoint, required=False)),
-                'actionlabel': self._get_translation_field(WIRE, 'actionLabel', input_endpoint, 'inputActionLabel', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', input_endpoint, required=False)),
+                'label': self._get_translation_field(RDFS, 'label', input_endpoint, var_name + '_label', required=False, type='vdef', variable=var_name, field='label'),
+                'description': self._get_translation_field(DCTERMS, 'description', input_endpoint, var_name + '_description', required=False, type='vdef', variable=var_name, field='description'),
+                'actionlabel': self._get_translation_field(WIRE, 'inputActionLabel', input_endpoint, var_name + '_actionlabel', required=False, type='vdef', variable=var_name, field='actionlabel'),
                 'friendcode': self._get_field(WIRE, 'friendcode', input_endpoint, required=False),
             })
 
-        for output_endpoint in self._graph.objects(wiring_element, WIRE['hasOutputEndpoint']):
+        sorted_outputs = sorted(self._graph.objects(wiring_element, WIRE['hasOutputEndpoint']), key=lambda output: possible_int(self._get_field(WIRE, 'index', output, required=False)))
+
+        for output_endpoint in sorted_outputs:
+            var_name = self._get_field(DCTERMS, 'title', output_endpoint, required=True)
             self._info['wiring']['outputs'].append({
-                'name': self._get_field(DCTERMS, 'title', output_endpoint, required=False),
+                'name': var_name,
                 'type': self._get_field(WIRE, 'type', output_endpoint, required=False),
-                'label': self._get_translation_field(RDFS, 'label', output_endpoint, 'outputLabel', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', output_endpoint, required=False)),
-                'description': self._get_translation_field(DCTERMS, 'description', output_endpoint, 'outputDescription', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', output_endpoint, required=False)),
+                'label': self._get_translation_field(RDFS, 'label', output_endpoint, var_name + '_label', required=False, type='vdef', variable=var_name, field='label'),
+                'description': self._get_translation_field(DCTERMS, 'description', output_endpoint, var_name + '_description', required=False, type='vdef', variable=var_name, field='description'),
                 'friendcode': self._get_field(WIRE, 'friendcode', output_endpoint, required=False),
             })
 
@@ -349,7 +358,6 @@ class RDFTemplateParser(object):
 
     def _parse_widget_info(self):
 
-        self._info['iphone_image_uri'] = self._get_url_field('iphone_image_uri', WIRE, 'hasiPhoneImageUri', self._rootURI, required=False)
         # Preference info
         self._info['preferences'] = []
 
@@ -357,11 +365,12 @@ class RDFTemplateParser(object):
         sorted_preferences = sorted(self._graph.objects(self._rootURI, WIRE['hasPlatformPreference']), key=lambda pref: possible_int(self._get_field(WIRE, 'index', pref, required=False)))
 
         for preference in sorted_preferences:
+            var_name = self._get_field(DCTERMS, 'title', preference, required=True)
             preference_info = {
-                'name': self._get_field(DCTERMS, 'title', preference, required=False),
+                'name': var_name,
                 'type': self._get_field(WIRE, 'type', preference, required=False),
-                'label': self._get_translation_field(RDFS, 'label', preference, 'prefLabel', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', preference, required=False)),
-                'description': self._get_translation_field(DCTERMS, 'description', preference, 'prefDescription', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', preference, required=False)),
+                'label': self._get_translation_field(RDFS, 'label', preference, var_name + '_label', required=False, type='vdef', variable=var_name, field='label'),
+                'description': self._get_translation_field(DCTERMS, 'description', preference, var_name + '_description', required=False, type='vdef', variable=var_name, field='description'),
                 'readonly': self._get_field(WIRE, 'readonly', preference, required=False).lower() == 'true',
                 'default_value': self._get_field(WIRE, 'default', preference, required=False),
                 'value': self._get_field(WIRE, 'value', preference, required=False, default=None),
@@ -371,9 +380,9 @@ class RDFTemplateParser(object):
                 preference_info['options'] = []
 
                 sorted_options = sorted(self._graph.objects(preference, WIRE['hasOption']), key=lambda option: possible_int(self._get_field(WIRE, 'index', option, required=False)))
-                for option in sorted_options:
+                for option_index, option in enumerate(sorted_options):
                     preference_info['options'].append({
-                        'label': self._get_translation_field(DCTERMS, 'title', option, 'optionName', required=False, type='upo', variable=preference_info['name'], option='__MSG_optionName__'),
+                        'label': self._get_translation_field(DCTERMS, 'title', option, var_name + '_option' + str(option_index) + '_label', required=False, type='upo', variable=preference_info['name'], option=option_index),
                         'value': self._get_field(WIRE, 'value', option, required=False),
                     })
 
@@ -384,11 +393,12 @@ class RDFTemplateParser(object):
 
         sorted_properties = sorted(self._graph.objects(self._rootURI, WIRE['hasPlatformStateProperty']), key=lambda prop: possible_int(self._get_field(WIRE, 'index', prop, required=False)))
         for prop in sorted_properties:
+            var_name = self._get_field(DCTERMS, 'title', prop, required=True)
             self._info['properties'].append({
-                'name': self._get_field(DCTERMS, 'title', prop, required=False),
+                'name': var_name,
                 'type': self._get_field(WIRE, 'type', prop, required=False),
-                'label': self._get_translation_field(RDFS, 'label', prop, 'propLabel', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', prop, required=False)),
-                'description': self._get_translation_field(DCTERMS, 'description', prop, 'propDescription', required=False, type='vdef', variable=self._get_field(DCTERMS, 'title', prop, required=False)),
+                'label': self._get_translation_field(RDFS, 'label', prop, var_name + '_label', required=False, type='vdef', variable=var_name, field='label'),
+                'description': self._get_translation_field(DCTERMS, 'description', prop, var_name + '_description', required=False, type='vdef', variable=var_name, field='description'),
                 'default_value': self._get_field(WIRE, 'default', prop, required=False),
                 'secure': self._get_field(WIRE, 'secure', prop, required=False).lower() == 'true',
             })
@@ -402,13 +412,26 @@ class RDFTemplateParser(object):
             xhtml_element = self._get_field(USDL, 'utilizedResource', self._rootURI, id_=True)
 
             self._info['code_url'] = unicode(xhtml_element)
-            self._info['code_content_type'] = self._get_field(DCTERMS, 'format', xhtml_element, required=False)
-            if self._info['code_content_type'] == '':
-                self._info['code_content_type'] = 'text/html'
+            content_type, parameters = parse_mime_type(self._get_field(DCTERMS, 'format', xhtml_element, required=False))
+
+            self._info['code_content_type'] = 'text/html'
+            self._info['code_charset'] = 'utf-8'
+            if content_type != '':
+                self._info['code_content_type'] = content_type
+                if 'charset' in parameters:
+                    self._info['code_charset'] = parameters['charset'].lower()
+
+            elif len(parameters) > 1:
+                raise Exception('Invalid code content type')
 
             self._info['code_uses_platform_style'] = self._get_field(WIRE, 'usePlatformStyle', xhtml_element, required=False).lower() == 'true'
             self._info['code_cacheable'] = self._get_field(WIRE, 'codeCacheable', xhtml_element, required=False, default='true').lower() == 'true'
 
+            rendering_element = self._get_field(WIRE, 'hasPlatformRendering', self._rootURI, id_=True, required=False)
+
+            self._info['widget_width'] = self._get_field(WIRE, 'renderingWidth', rendering_element, required=False)
+            self._info['widget_height'] = self._get_field(WIRE, 'renderingHeight', rendering_element, required=False)
+
         elif self._info['type'] == 'operator':
             # The tamplate has 1-n javascript elements
 
@@ -422,13 +445,6 @@ class RDFTemplateParser(object):
             if not len(self._info['js_files']) > 0:
                 raise TemplateParseException(_('Missing required field: Javascript files'))
 
-            self._info['code_content_type'] = 'text/javascript'
-
-        rendering_element = self._get_field(WIRE, 'hasPlatformRendering', self._rootURI, id_=True, required=False)
-
-        self._info['widget_width'] = self._get_field(WIRE, 'renderingWidth', rendering_element, required=False)
-        self._info['widget_height'] = self._get_field(WIRE, 'renderingHeight', rendering_element, required=False)
-
     def _parse_translation_catalogue(self):
         self._info['default_lang'] = 'en'
         self._info['translations'] = self._translations
@@ -438,7 +454,7 @@ class RDFTemplateParser(object):
 
         preferences = {}
 
-        for preference in self._graph.objects(self._rootURI, WIRE_M['hasWorkspacePreference']):
+        for preference in self._graph.objects(self._rootURI, WIRE_M['hasMashupPreference']):
             preferences[self._get_field(DCTERMS, 'title', preference)] = self._get_field(WIRE, 'value', preference)
 
         self._info['preferences'] = preferences
