@@ -119,6 +119,7 @@
                 window.open(Wirecloud.URLs.DJANGO_ADMIN, '_blank');
             }));
         }
+        user_menu.append(new Wirecloud.ui.TutorialSubMenu());
         user_menu.append(new StyledElements.Separator());
         user_menu.append(new StyledElements.MenuItem(gettext('Sign out'), OpManagerFactory.getInstance().logout));
     };
@@ -202,7 +203,7 @@
     WirecloudHeader.prototype._notifyWorkspaceLoaded = function _notifyWorkspaceLoaded(workspace) {
         if (this.footer == null) {
             this.footer = document.createElement('footer');
-            this.footer.innerHTML = '<div>2013 © <a href="http://fi-ware.eu/">FI-WARE</a>. Usage of FI-LAB services subject to acceptance of <a href="http://wiki.fi-ware.eu/FI-LAB_Terms_and_Conditions">Terms and Conditions</a> and <a href="http://wiki.fi-ware.eu/FI-LAB_Terms_and_Conditions">Terms and Conditions</a></div>';
+            this.footer.innerHTML = '<div>2013 © <a href="http://fi-ware.eu/">FI-WARE</a>. The use of FI-LAB services is subject to the acceptance of the <a href="http://wiki.fi-ware.eu/FI-LAB_Terms_and_Conditions">Terms and Conditions</a> and the <a href="http://forge.fi-ware.eu/plugins/mediawiki/wiki/fiware/index.php/FI-LAB_Personal_Data_Protection_Policy">Personal Data Protection Policy</a></div>';
             LayoutManagerFactory.getInstance().mainLayout.getSouthContainer().appendChild(this.footer);
             LayoutManagerFactory.getInstance().mainLayout.repaint();
         }
