@@ -21,6 +21,7 @@
 import json
 from cStringIO import StringIO
 import os
+import zipfile
 
 from django.conf import settings
 from django.db import IntegrityError
@@ -39,7 +40,7 @@ from wirecloud.commons.utils import downloader
 from wirecloud.commons.utils.http import authentication_required, build_error_response, get_content_type, supported_request_mime_types
 from wirecloud.commons.utils.template import TemplateParseException
 from wirecloud.commons.utils.transaction import commit_on_http_success
-from wirecloud.commons.utils.wgt import WgtFile
+from wirecloud.commons.utils.wgt import InvalidContents, WgtFile
 from wirecloud.platform.markets.utils import get_market_managers
 from wirecloud.platform.models import Widget, IWidget
 from wirecloud.platform.localcatalogue.signals import resource_uninstalled
@@ -130,17 +131,25 @@ class ResourceCollection(Resource):
                     return build_error_response(request, 409, _('Content cannot be downloaded'))
 
             if packaged:
-                downloaded_file = StringIO(downloaded_file)
-                file_contents = WgtFile(downloaded_file)
+
+                try:
+                    downloaded_file = StringIO(downloaded_file)
+                    file_contents = WgtFile(downloaded_file)
+
+                except zipfile.BadZipfile, e:
+
+                    return build_error_response(request, 400, unicode(e))
+
             else:
                 file_contents = downloaded_file
 
         try:
+
             resource = install_resource_to_user(request.user, file_contents=file_contents, templateURL=templateURL, packaged=packaged, raise_conflicts=force_create)
 
-        except TemplateParseException, e:
+        except (TemplateParseException, InvalidContents), e:
 
-            return build_error_response(request, 400, unicode(e.msg))
+            return build_error_response(request, 400, unicode(e))
 
         except IntegrityError:
 
@@ -204,3 +213,16 @@ class ResourceEntry(Resource):
                 return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
 
         return HttpResponse(status=204)
+
+
+class ResourceDescriptionEntry(Resource):
+
+    @authentication_required
+    def read(self, request, vendor, name, version):
+
+        resource = get_object_or_404(CatalogueResource, vendor=vendor, short_name=name, version=version)
+        if not request.user.is_superuser and not resource.is_available_for(request.user):
+            return HttpResponse(status=403)
+
+        resource_info = resource.get_processed_info(request)
+        return HttpResponse(json.dumps(resource_info), mimetype='application/json; charset=UTF-8')
