@@ -258,7 +258,7 @@
     };
 
     CatalogueView.prototype.refresh_search_results = function () {
-        this.viewsByName.search.pagination.refresh();
+        this.viewsByName.search.source.refresh();
     };
 
     window.CatalogueView = CatalogueView;
