@@ -312,6 +312,29 @@ class ApplicationMashupAPI(WirecloudTestCase):
         response = self.client.post(url, json.dumps(data), content_type='application/json', HTTP_ACCEPT='application/json')
         self.assertEqual(response.status_code, 409)
 
+    def test_workspace_collection_post_allow_renaming(self):
+
+        url = reverse('wirecloud.workspace_collection')
+
+        # Authenticate
+        self.client.login(username='user_with_workspaces', password='admin')
+
+        # Make the request
+        data = {
+            'allow_renaming': True,
+            'name': 'ExistingWorkspace'
+        }
+        response = self.client.post(url, json.dumps(data), content_type='application/json', HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 201)
+        response_data = json.loads(response.content)
+        self.assertTrue(isinstance(response_data, dict))
+        self.assertTrue('id' in response_data)
+        self.assertNotEqual(response_data['name'], 'ExistingWorkspace')
+        self.assertTrue(isinstance(response_data['wiring'], dict))
+
+        # Workspace should be created
+        self.assertTrue(Workspace.objects.filter(creator=4, name=response_data['name']).exists())
+
     def test_workspace_collection_post_creation_from_nonexistent_mashup(self):
 
         url = reverse('wirecloud.workspace_collection')
@@ -813,6 +836,11 @@ class ApplicationMashupAPI(WirecloudTestCase):
         response_data = json.loads(response.content)
         self.assertTrue(isinstance(response_data, dict))
 
+    def test_iwidget_collection_post_bad_request_syntax(self):
+
+        url = reverse('wirecloud.iwidget_collection', kwargs={'workspace_id': 1, 'tab_id': 1})
+        check_post_bad_request_syntax(self, url)
+
     def test_iwidget_entry_post_requires_authentication(self):
 
         url = reverse('wirecloud.iwidget_entry', kwargs={'workspace_id': 2, 'tab_id': 101, 'iwidget_id': 2})
@@ -856,6 +884,11 @@ class ApplicationMashupAPI(WirecloudTestCase):
         iwidget = IWidget.objects.get(pk=2)
         self.assertEqual(iwidget.name, 'New Name')
 
+    def test_iwidget_entry_post_bad_request_syntax(self):
+
+        url = reverse('wirecloud.iwidget_entry', kwargs={'workspace_id': 2, 'tab_id': 101, 'iwidget_id': 2})
+        check_post_bad_request_syntax(self, url)
+
     def test_iwidget_preferences_entry_post_requires_authentication(self):
 
         url = reverse('wirecloud.iwidget_preferences', kwargs={'workspace_id': 2, 'tab_id': 101, 'iwidget_id': 2})
@@ -907,6 +940,11 @@ class ApplicationMashupAPI(WirecloudTestCase):
         )
         self.assertEqual(variable_value.value, 'new value')
 
+    def test_iwidget_preferences_entry_post_bad_request_syntax(self):
+
+        url = reverse('wirecloud.iwidget_preferences', kwargs={'workspace_id': 2, 'tab_id': 101, 'iwidget_id': 2})
+        check_post_bad_request_syntax(self, url)
+
     def test_iwidget_entry_delete_requires_authentication(self):
 
         url = reverse('wirecloud.iwidget_entry', kwargs={'workspace_id': 2, 'tab_id': 101, 'iwidget_id': 2})
@@ -1031,6 +1069,20 @@ class ResourceManagementAPI(WirecloudTestCase):
         self.assertIn('version', response_data)
         self.assertEqual(response_data['version'], '1.0')
 
+    def test_resource_collection_post_widget_invalid_html_encoding(self):
+
+        url = reverse('wirecloud_showcase.resource_collection')
+
+        # Authenticate
+        self.client.login(username='admin', password='admin')
+
+        # Make the request
+        with open(os.path.join(self.shared_test_data_dir, 'Wirecloud_Test_Invalid_HTML_Encoding_1.0.wgt'), 'rb') as f:
+            response = self.client.post(url, data={'file': f}, HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 400)
+        response_data = json.loads(response.content)
+        self.assertTrue(isinstance(response_data, dict))
+
     def test_resource_collection_post_operator(self):
 
         url = reverse('wirecloud_showcase.resource_collection')
@@ -1118,6 +1170,21 @@ class ResourceManagementAPI(WirecloudTestCase):
         self.assertIn('name', response_data)
         self.assertIn('version', response_data)
 
+    def test_resource_collection_post_using_bad_packaged_resouce_from_uri(self):
+
+        url = reverse('wirecloud_showcase.resource_collection')
+
+        # Authenticate
+        self.client.login(username='admin', password='admin')
+
+        # Make the request
+        data = {
+            'packaged': True,
+            'template_uri': 'http://localhost:8001/test-mashup.rdf'
+        }
+        response = self.client.post(url, json.dumps(data), content_type="application/json", HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 400)
+
     def test_resource_collection_post_using_octet_stream_error(self):
 
         url = reverse('wirecloud_showcase.resource_collection')
@@ -1259,6 +1326,38 @@ class ExtraApplicationMashupAPI(WirecloudTestCase):
         response_data = json.loads(response.content)
         self.assertTrue(isinstance(response_data, dict))
 
+    def test_resource_description_entry_get_requires_authentication(self):
+
+        url = reverse('wirecloud_showcase.resource_description_entry', kwargs={'vendor': 'Wirecloud', 'name': 'Test', 'version': '1.0'})
+        check_get_requires_authentication(self, url)
+
+    def test_resource_description_entry_read(self):
+
+        resource_id = [
+            'Wirecloud',
+            'Test',
+            '1.0'
+        ]
+        url = reverse('wirecloud_showcase.resource_description_entry', args=resource_id)
+
+        # Authenticate
+        self.client.login(username='admin', password='admin')
+
+        # Make the request
+        response = self.client.get(url, HTTP_ACCEPT='application/json')
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response['Content-Type'].split(';', 1)[0], 'application/json')
+
+    def test_resource_description_entry_read_requires_permission(self):
+
+        resource_id = (
+            'Wirecloud',
+            'TestOperator',
+            '1.0',
+        )
+        url = reverse('wirecloud_showcase.resource_description_entry', args=resource_id)
+        check_get_requires_permission(self, url)
+
     def test_market_collection_get_requires_authentication(self):
 
         url = reverse('wirecloud.market_collection')
