@@ -154,10 +154,10 @@ class VariableDef(TransModel):
     )
     secure = models.BooleanField(_('Secure'), default=False)
     aspect = models.CharField(_('Aspect'), max_length=4, choices=ASPECTS)
-    label = models.CharField(_('Label'), max_length=150, null=True)
-    action_label = models.CharField(_('Action label'), max_length=50, null=True)
-    description = models.CharField(_('Description'), max_length=250, null=True)
-    friend_code = models.CharField(_('Friend code'), max_length=30, null=True)
+    label = models.CharField(_('Label'), max_length=150, null=False, blank=True, default='')
+    action_label = models.CharField(_('Action label'), max_length=50, null=False, blank=True, default='')
+    description = models.CharField(_('Description'), max_length=250, null=False, blank=True, default='')
+    friend_code = models.CharField(_('Friend code'), max_length=30, null=False, blank=True, default='')
     readonly = models.BooleanField(_('Read only'), default=False)
     default_value = models.TextField(_('Default value'), blank=True, null=True)
     value = models.TextField(_('Value'), blank=True, null=True)
